@@ -1,10 +1,9 @@
-from .diagnose import Diagnose
 from .normalise import Normalise
 
 # Metadata
 __doc__ = "Package to help with normalizing data needed for the platform!"
 # Github CI/CD greps for the version number.
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 __author__ = "Realstats"
-__email__ = "hello@realstats.com"
+__email__ = "m.masselink@yahoo.com"
 __license__ = "MIT"
